@@ -121,12 +121,11 @@ the top of the message."
   "Email address domain to send control message to.")
 
 (defvar debian-bts-control-minor-mode nil)
-(defvar debian-bts-control-minor-mode-map nil
+(defvar debian-bts-control-minor-mode-map
+  (let ((map (make-sparse-keymap)))
+    (define-key map "\C-c\C-b" 'debian-bts-control)
+    map)
   "Keymap for `debian-bts-control' minor mode.")
-(if debian-bts-control-minor-mode-map
-    nil
-  (setq debian-bts-control-minor-mode-map (make-sparse-keymap))
-  (define-key debian-bts-control-minor-mode-map "\C-c\C-b" 'debian-bts-control))
 
 (easy-menu-define debian-bts-control-menu debian-bts-control-minor-mode-map
   "Debian Bug Mode Menu"
@@ -303,32 +302,28 @@ a negative prefix argument turns it off.
 \\<debian-bts-control-minor-mode-map>
 \\[debian-bts-control]\t\tAdd a control command to the current message."
   (interactive "P")
-  (set (make-local-variable 'debian-bts-control-minor-mode)
-       (if arg
-           (> (prefix-numeric-value arg) 0)
-         (not debian-bts-control-minor-mode)))
-  (cond
-   (debian-bts-control-minor-mode                 ;Setup the minor-mode
-    (if (fboundp 'font-lock-add-keywords)
-        (font-lock-add-keywords nil debian-bts-control-font-lock-keywords t))
-    )))
+  (setq-local debian-bts-control-minor-mode
+              (if arg
+                  (> (prefix-numeric-value arg) 0)
+                (not debian-bts-control-minor-mode)))
+  (when (and debian-bts-control-minor-mode ; Setup the minor-mode
+             (fboundp 'font-lock-add-keywords))
+    (font-lock-add-keywords nil debian-bts-control-font-lock-keywords t)))
 
 ;; Install ourselves:
-(or (assq 'debian-bts-control-minor-mode minor-mode-alist)
-    (setq minor-mode-alist
-          (cons '(debian-bts-control-minor-mode " DBugC") minor-mode-alist)))
-(or (assq 'debian-bts-control-minor-mode minor-mode-map-alist)
-    (setq minor-mode-map-alist
-          (cons (cons 'debian-bts-control-minor-mode
-                      debian-bts-control-minor-mode-map)
-                minor-mode-map-alist)))
+(unless (assq 'debian-bts-control-minor-mode minor-mode-alist)
+  (push '(debian-bts-control-minor-mode " DBugC") minor-mode-alist))
+(unless (assq 'debian-bts-control-minor-mode minor-mode-map-alist)
+  (push (cons 'debian-bts-control-minor-mode debian-bts-control-minor-mode-map)
+        minor-mode-map-alist))
 
 (defvar debian-bts-control-alist
-  '(("reassign") ("severity") ("reopen") ("submitter") ("forwarded")
-    ("notforwarded") ("retitle") ("clone") ("merge") ("unmerge")
-    ("tags") ("package") ("owner") ("noowner") ("found")
-    ("notfound") ("fixed") ("notfixed") ("block") ("unblock") ("archive")
-    ("unarchive") ("affects") ("forcemerge") ("summary"))
+  ;; The name is historical, this is not an alist.
+  '("reassign" "severity" "reopen" "submitter" "forwarded"
+    "notforwarded" "retitle" "clone" "merge" "unmerge"
+    "tags" "package" "owner" "noowner" "found"
+    "notfound" "fixed" "notfixed" "block" "unblock" "archive"
+    "unarchive" "affects" "forcemerge" "summary")
   "List of available commands at control@bugs.debian.org.")
 
 (defun debian-bts-bug-number-at-point ()
@@ -347,10 +342,9 @@ a negative prefix argument turns it off.
         (if (re-search-forward (concat "\\([0-9]+\\)@" debian-bts-emaildomain)
                                (mail-header-end) t)
             (setq default-number (match-string-no-properties 1)))))
-    (if default-number
-        (read-string (format "%s [%s]: " prompt default-number)
-                     nil nil default-number)
-      (read-string (format "%s: " prompt)))))
+    (read-string (format (if default-number "%s [%s]: " "%s: ") prompt
+                         default-number)
+                 nil nil default-number)))
 
 ;;;###autoload
 (defun debian-bts-control (action &optional arg)
@@ -368,8 +362,7 @@ in `debian-bts-control-modes-to-reuse'."
   (let ((number-default (debian-bts-bug-number-at-point)))
     (cond
      ((or arg
-          (and (car (memq t (mapcar #'(lambda (item) (eq item major-mode))
-                                    debian-bts-control-modes-to-reuse)))
+          (and (memq major-mode debian-bts-control-modes-to-reuse)
                (not debian-bts-control-minor-mode)))
       (debian-bug--set-CC debian-bts-emailaddress
                           (concat
@@ -453,7 +446,7 @@ in `debian-bts-control-modes-to-reuse'."
                           number-default))
              (sign (completing-read
                     (concat verbose "[ + | - | = ] ")
-                    '(("+") ("-") ("=")) nil nil))
+                    '("+" "-" "=") nil nil))
              (package (completing-read
                        (concat verbose "Package affected: ")
                        (debian-bug-fill-packages-obarray) nil nil)))
@@ -754,7 +747,7 @@ in `debian-bts-control-modes-to-reuse'."
                           (concat verbose "Bug number")
                           number-default))
              (add (completing-read "+, -, = (default +): "
-                                   '(("+") ("-") ("=")) nil t nil nil "+"))
+                                   '("+" "-" "=") nil t nil nil "+"))
              (tag (completing-read "Tag: " debian-bug-alltags-alist nil t)))
         (insert (format "tags %s %s %s\n" bug-number add tag))))
      ((string-equal "close" action)
