@@ -129,16 +129,6 @@
 
 ;; XEmacs compatibility
 (eval-and-compile
-  (unless (fboundp 'line-beginning-position)
-    (defun line-beginning-position ()
-      (save-excursion
-        (beginning-of-line)
-        (point))))
-  (unless (fboundp 'line-end-position)
-    (defun line-end-position ()
-      (save-excursion
-        (end-of-line)
-        (point))))
   (unless (fboundp 'match-string-no-properties)
     (defalias 'match-string-no-properties 'match-string)))
 
@@ -155,14 +145,12 @@
   :type 'face
   :group 'debian-control)
 
-(defvar debian-control-syntax-table nil
+(defvar debian-control-syntax-table
+  (let ((table (make-syntax-table)))
+    (modify-syntax-entry ?\n "> " table)
+    table)
   "Syntax table used in debian-control-mode buffers.")
 
-(if debian-control-syntax-table
-    ()
-  (setq debian-control-syntax-table (make-syntax-table))
-  (modify-syntax-entry ?\n "> " debian-control-syntax-table))
-
 ;; FIXME: As of policy 3.5.6.0, the allowed characters in a field name
 ;; are not specified.  So we just go with "word constituent" or '-'
 ;; characters before a colon.
@@ -300,31 +288,27 @@ It should be immediately followed by a non-slash character.")
   "A major mode for editing Debian control files (i.e. debian/control)."
   (set-syntax-table debian-control-syntax-table)
   ;; Comments
-  (make-local-variable 'comment-start-skip)  ;Need this for font-lock...
-  (setq comment-start-skip "^#+\s-*")
-  (make-local-variable 'comment-start)
-  (make-local-variable 'comment-end)
-  (setq comment-start "#"
-        comment-end "")
+  (setq-local comment-start-skip "^#+\s-*")  ;Need this for font-lock...
+  (setq-local comment-start "#")
+  (setq-local comment-end "")
 
   ;; Support # style comments
   (setq-local syntax-propertize-function
               (syntax-propertize-rules ("^\\(#\\)" (1 "<"))))
 
-  (make-local-variable 'font-lock-defaults)
-  (setq font-lock-defaults
-        '(debian-control-font-lock-keywords
-          nil           ;;; Keywords only? No, let it do syntax via table.
-          nil           ;;; case-fold?
-          nil           ;;; Local syntax table.
-          nil           ;;; Use `backward-paragraph' ? No
-          ))
-  (set (make-local-variable 'fill-paragraph-function)
-       #'debian-control-mode-fill-paragraph)
+  (setq-local font-lock-defaults
+              '(debian-control-font-lock-keywords
+                nil           ;;; Keywords only? No, let it do syntax via table.
+                nil           ;;; case-fold?
+                nil           ;;; local syntax table alist
+                ))
+  (setq-local fill-paragraph-function
+              #'debian-control-mode-fill-paragraph)
   (make-local-variable 'after-change-functions)
   (push 'debian-control-mode-after-change-function after-change-functions)
-  (set (make-local-variable 'imenu-generic-expression)
-       '((nil "^\\(Package\\|Source\\):\\s-*\\([-a-zA-Z0-9+.]+?\\)\\s-*$" 2)))
+  (setq-local imenu-generic-expression
+              '((nil "^\\(Package\\|Source\\):\\s-*\\([-a-zA-Z0-9+.]+?\\)\\s-*$"
+                     2)))
 
   (define-key debian-control-mode-map (kbd "C-c C-b") 'debian-control-view-package-bugs)
   (define-key debian-control-mode-map (kbd "C-c C-p") 'debian-control-visit-policy)
@@ -338,7 +322,7 @@ It should be immediately followed by a non-slash character.")
       (goto-address))
   (let ((after-change-functions nil))
     (debian-control-mode-after-change-function (point-min) (point-max) 0))
-  (dpkg-dev-common-utils--add-debputy-settings 'debian-control-mode))
+  (dpkg-dev-common-utils--add-debputy-settings))
 
 (defun debian-control-mode-after-change-function (beg end len)
   (save-excursion
@@ -350,27 +334,19 @@ It should be immediately followed by a non-slash character.")
             (goto-char beg)
             (beginning-of-line)
             (while (< (point) end)
-              (cond ((looking-at (concat "^\\(Source:\\)\\s-*"
-                                         debian-control-package-name-regexp
-                                         "\\s-*$"))
-                     (add-text-properties
-                      (match-beginning 2) (match-end 2)
-                      `(mouse-face
-                        highlight
-                        debian-control-mode-package ,(match-string 2)
-                        help-echo "C-mouse-2: View bugs for this source package"
-                        keymap ,debian-control-mode-package-name-keymap)))
-                    ((looking-at (concat "^\\(Package:\\)\\s-*"
-                                         debian-control-package-name-regexp
-                                         "\\s-*$"))
-                     (add-text-properties
-                      (match-beginning 2) (match-end 2)
-                      `(mouse-face
-                        highlight
-                        debian-control-mode-package ,(match-string 2)
-                        help-echo "C-mouse-2: View bugs for this binary package"
-                        keymap ,debian-control-mode-package-name-keymap)))
-                    (t nil))
+              (when (looking-at (concat "^\\(Source\\|Package\\):\\s-*"
+                                        debian-control-package-name-regexp
+                                        "\\s-*$"))
+                (add-text-properties
+                 (match-beginning 2) (match-end 2)
+                 `(mouse-face
+                   highlight
+                   debian-control-mode-package ,(match-string 2)
+                   help-echo ,(format "C-mouse-2: View bugs for this %s package"
+                                      (if (string-prefix-p "S" (match-string 1))
+                                          "source"
+                                        "binary"))
+                   keymap ,debian-control-mode-package-name-keymap)))
               (forward-line 1)))
         (set-match-data data)
         (set-buffer-modified-p modified)))))
@@ -406,7 +382,7 @@ It should be immediately followed by a non-slash character.")
             (beginning-of-line)
             (looking-at debian-control-field-regexp))
           (setq beg (match-end 0)
-                end (line-end-position))
+                end (point-at-eol))
         ;; Otherwise, we're looking at a description; handle filling
         ;; areas separated with "."  specially
         (setq beg (save-excursion
@@ -440,7 +416,7 @@ It should be immediately followed by a non-slash character.")
                               (beginning-of-line)
                               (looking-at "^\\(Package\\|Source\\)"))
                             (re-search-backward "^\\(Package\\|Source\\)" nil t))
-                        (not (not (string-match "Package" (match-string 0))))
+                        (string-prefix-p "P" (match-string 0))
                       (error "Couldn't find Package or Source field")))
           (fields (if binary-p
                       debian-control-binary-fields
@@ -449,7 +425,7 @@ It should be immediately followed by a non-slash character.")
      (list
       binary-p
       (completing-read (format "Add %s package field: " (if binary-p "binary" "source"))
-                       (mapcar #'(lambda (x) (cons x nil)) fields)))))
+                       fields))))
   (require 'cl-lib)
   (let ((fields (if binary
                     debian-control-binary-fields
@@ -469,23 +445,22 @@ It should be immediately followed by a non-slash character.")
                (point))))
     (save-restriction
       (narrow-to-region beg end)
-      (let ((curfields (let ((result nil))
-                         (goto-char (point-min))
-                         (while (not (eobp))
-                           (when (looking-at debian-control-field-regexp)
-                             (push (cons (seq-subseq
-                                          ;; Text properties are evil
-                                          (match-string-no-properties 1)
-                                          0
-                                          ;; Strip off the ':'
-                                          (- (match-end 1)
-                                             (match-beginning 1)
-                                             1))
-                                         (match-beginning 0))
-                                   result))
-                           (forward-line 1))
-                         result))
-            (x nil))
+      (let ((curfields nil) x)
+        ;; Populate curfields
+        (goto-char (point-min))
+        (while (not (eobp))
+          (when (looking-at debian-control-field-regexp)
+            (push (cons (seq-subseq
+                         ;; Text properties are evil
+                         (match-string-no-properties 1)
+                         0
+                         ;; Strip off the ':'
+                         (- (match-end 1)
+                            (match-beginning 1)
+                            1))
+                        (match-beginning 0))
+                  curfields))
+          (forward-line 1))
         ;; If the field is already present, just jump to it
         (if (setq x (assoc field curfields))
             (goto-char (cdr x))
@@ -522,8 +497,7 @@ text file."
   (interactive
    (list (intern
           (completing-read "Policy format: "
-                           (mapcar #'(lambda (x) (cons x 0))
-                                   '("html" "text" "checklist"))
+                           '("html" "text" "checklist")
                            nil t))))
   (cl-case format
     (text
@@ -536,9 +510,8 @@ text file."
      (browse-url
       (if (file-exists-p "/usr/share/doc/debian-policy/policy.html/index.html")
           "file:///usr/share/doc/debian-policy/policy.html/index.html"
-        (prog1
-            "http://www.debian.org/doc/debian-policy"
-          (message "Note: package `debian-policy' not installed, using web version")))))
+        (message "Note: package `debian-policy' not installed, using web version")
+        "http://www.debian.org/doc/debian-policy")))
     (t
      (error "Unknown format %s for policy" format))))
 
@@ -546,10 +519,10 @@ text file."
   "Find-file a possibly compressed FILE"
   (require 'jka-compr)
   (let ((installed (jka-compr-installed-p)))
-    (if (not installed)
+    (unless installed
         (auto-compression-mode t))
     (find-file file)
-    (if (not installed)
+    (unless installed
         (auto-compression-mode -1))))
 
 (defun debian-control-mode-bugs-mouse-click (event)
@@ -568,7 +541,7 @@ text file."
       (while (not (eobp))
         (when (looking-at "^\\(Package\\|Source\\):\\s-*\\([-a-zA-Z0-9+.]+?\\)\\s-*$")
           (push (concat
-                 (if (save-match-data (string-match "Source" (match-string 1)))
+                 (if (string-prefix-p "S" (match-string 1))
                      "src:"
                    "")
                  (match-string-no-properties 2)) result))
@@ -580,8 +553,7 @@ text file."
   (interactive
    (list
     (completing-read "View bugs for package: "
-                     (mapcar #'(lambda (x) (cons x 0))
-                             (debian-control-mode-bug-package-names))
+                     (debian-control-mode-bug-package-names)
                      nil t)))
   (browse-url (concat "http://bugs.debian.org/" package)))
 
